from pathlib import Path

__software__ = "fbc_curation"
__version__ = "0.1.6"
__citation__ = "https://doi.org/10.5281/zenodo.3708271"

EXAMPLE_PATH = Path(__file__).parent / "examples"
